@@ -31,9 +31,9 @@ from forgeimporters.base import (
         ToolImportForm,
         )
 
-from forgewiki.scripts.wiki_from_trac.extractors import WikiExporter
-from forgewiki.scripts.wiki_from_trac.loaders import load_data
-from forgewiki.scripts.wiki_from_trac.wiki_from_trac import WikiFromTrac
+from tracwikiimporter.scripts.wiki_from_trac.extractors import WikiExporter
+from tracwikiimporter.scripts.wiki_from_trac.loaders import load_data
+from tracwikiimporter.scripts.wiki_from_trac.wiki_from_trac import WikiFromTrac
 from forgewiki.wiki_main import ForgeWikiApp
 
 
